<?php
/**
 * クラススクリプト
 * 
 * 金魚屋開発支援シリーズ
 *
 * @package Joomla
 * @mambot bot_kingyoya_adminhtml
 * @copyright (C) 2008 金魚屋見聞録
 * @author 金魚屋・Ｊ・龍角
 * @version 1.0.0
 */

// no direct access
defined( '_VALID_MOS' ) or die( 'Restricted access' );

/**
 * 管理画面HTML生成クラス
 */
class mosKingyoyaAdminHTML {

	/**
	 * HTML生成クラスオブジェクト作成
	 * @static
	 * @param string type
	 * @param string option
	 */
	function factory($type, $option) {
		$html = null;
		if (!$option || !is_string($option)) {
			trigger_error("Unvalid option: {$option}", E_USER_WARNING);
			return $html;
		}
		switch($type) {
			case 'list':
				$html = new mosKingyoyaAdminHTMLList($option);
				break;
			case 'form':
				$html = new mosKingyoyaAdminHTMLForm($option);
				break;
			default:
				trigger_error("Unknown type: {$type}", E_USER_WARNING);
				break;
		}
		return $html;
	}

	/**
	 * 一般的なヘッダを表示
	 * @static
	 * @param string title
	 * @param string class
	 */
	function showHeader($title, $class = null) {
		if (!$title || !is_string($title)) {
			trigger_error("Unvalid title: {$title}", E_USER_WARNING);
			return;
		}
		if ($class && !is_string($class)) {
			trigger_error("Unvalid option: {$class}", E_USER_WARNING);
			return;
		}
?>

<table class="adminheading">
	<tr>
		<th<?php if ($class) echo " class={$class}"; ?>><?php echo $title; ?></th>
	</tr>
</table>

<?php
	}

	/**
	 * 一般的なフォームヘッダを表示
	 * @static
	 * @param string option
	 */
	function showFormHeader($option) {
		if (!$option || !is_string($option)) {
			trigger_error("Unvalid option: {$option}", E_USER_WARNING);
			return;
		}
		mosCommonHTML::loadOverlib();
?>

<form action="index2.php" method="post" name="adminForm">
	<input type="hidden" name="option" value="<?php echo $option; ?>" />
	<input type="hidden" name="task" value="" />
	<input type="hidden" name="id" value="" />
	<input type="hidden" name="cid" value="" />
	<input type="hidden" name="boxchecked" value="" />

<?php
	}

	/**
	 * 一般的なフォームフッタを表示
	 * @static
	 */
	function showFormFooter() {
?>

</form>

<?php
	}
}

/**
 * 管理画面一覧HTML生成クラス
 */
class mosKingyoyaAdminHTMLList {

	/** @var string option */
	var $option = '';
	/** @var mosPageNav pageNav */
	var $pageNav = null;
	/** @var array field set */
	var $fileds = array();
	/** @var array row */
	var $rows = array();

	/**
	 * コンストラクタ
	 * @param string option
	 */
	function mosKingyoyaAdminHTMLList($option) {
		if (!$option || !is_string($option)) {
			trigger_error("Unvalid option: {$option}", E_USER_WARNING);
			return $html;
		}
		$this->option = $option;
	}

	/**
	 * pageNav を設定、または設定されているpageNav を返す
	 * @param mosPageNav pageNav
	 * @return mosPageNav
	 */
	function & pageNav($pageNav = null) {
		$pageNav and $this->pageNav =& $pageNav;
		return $this->pageNav;
	}

	/**
	 * 列定義を追加
	 * @param string name
	 * @param string title
	 * @param string task
	 * @param string width
	 */
	function appendField($name, $title, $task = null, $width = null) {
		$this->fields[] = array('name' => $name, 'title' => $title, 'task' => $task, 'width' => $width);
	}

	/**
	 * 行番号列定義を追加
	 * @param string title
	 * @param string width
	 */
	function appendRowNumberField($title, $width = null) {
		$this->fields[] = array('type' => 'rownumber', 'title' => $title, 'width' => $width);
	}

	/**
	 * チェックボックス列定義を追加
	 * @param string width
	 */
	function appendCheckboxField($width = null) {
		$this->fields[] = array('type' => 'checkbox', 'width' => $width);
	}

	/**
	 * 行オブジェクト作成
	 * @param mixed id
	 */
	function & createRow($id = null) {
		$row = new mosKingyoyaAdminHTMLListRow($id);
		return $row;
	}

	/**
	 * 行オブジェクトを追加
	 * @param mixed row
	 */
	function & appendRow($row) {
		if (!is_object($row)) {
			$row = new mosKingyoyaAdminHTMLListRow($row);
		}
		$this->rows[] =& $row;
		return $row;
	}

	/**
	 * 一覧を描画
	 */
	function show() {
	?>

<table class="adminlist">
	<tr align="left">
	<?php
	foreach ($this->fields as $field) {
		$type = isset($field['type']) ? $field['type'] : null;
		$title = isset($field['title']) ? $field['title'] : null;
		if ($width = $field['width']) {
			echo "<th width=\"{$width}\">";
		} else {
			echo '<th>';
		}
		switch($type) {
			case 'checkbox';
				$count = count($this->rows);
				echo '<input type="checkbox" name="toggle" value="" onclick="checkAll(',$count,');" />';
				break;
			default;
				echo $title;
				break;
		}
		echo "</th>\n";
	}
	?>

	</tr>
	<?php
	$i = 0;
	foreach ($this->rows as $row) {
		echo "<tr>\n";
		foreach ($this->fields as $field) {
			$type = isset($field['type']) ? $field['type'] : null;
			$name = isset($field['name']) ? $field['name'] : null;
			$task = isset($field['task']) ? $field['task'] : null;
			echo '<td>';
			switch($type) {
				case 'checkbox';
					echo mosHTML::idBox( $i, $row->id() );
					break;
				case 'rownumber';
					echo $this->pageNav->rowNumber($i);
					break;
				default;
					if ($task) {
						echo "<a href=\"index2.php?option={$this->option}&task={$task}&id={$row->id}\">";
					}
					if ($name === 'id') {
						echo $row->id();
					} else {
						echo $row->field($name);
					}
					if ($task) {
						echo '</a>';
					}
					break;
			}
			echo "</td>\n";
		}
		echo "</tr>\n";
		$i ++;
	}
	?>

</table>
	<?php

		if ($this->pageNav) {
			echo $this->pageNav->getListFooter();
		}

	}
}

/**
 * 管理画面一覧HTML生成行クラス
 */
class mosKingyoyaAdminHTMLListRow {

	/** @var mixed id */
	var $id = null;
	/** @var array field set */
	var $fields = array();

	/**
	 * コンストラクタ
	 * @param mixed id
	 */
	function mosKingyoyaAdminHTMLListRow($id = null) {
		$this->id = $id;
	}

	/**
	 * 行のＩＤを設定、または返す
	 * @param mixed id
	 * @return mixed
	 */
	function id($id = null) {
		isset($id) and $this->id = $id;
		return $this->id;
	}


	/**
	 * 列の値を設定、または返す
	 * @param string name
	 * @param string value
	 * @return string
	 */
	function field($name, $value = null) {
		if (!isset($this->fields[$name])) $this->fields[$name] = null;
		isset($value) and $this->fields[$name] = $value;
		return $this->fields[$name];
	}

}

/**
 * 管理画面フォームHTML生成クラス
 */
class mosKingyoyaAdminHTMLForm {
}
